from EIVData.csv_dataset import CSVData
from torch.utils.data import random_split

def load_data(seed=0, splitting_part=0.8, normalize=True):
    """
    Loads the wine quality dataset
    :param seed: Seed for splitting and shuffling the data.
    Defaults to 0.
    :param splitting_part: Which fraction of the data to use as training
    data. Defaults to 0.8.
    :normalize: Whether to normalize the data, defaults to True.
    :returns: wine_trainset, wine_testset
    """
    wine_dataset = CSVData('~/SharedData/AI/datasets/wine_quality_red/winequality-red.csv',
            class_name='quality',
            shuffle_seed=seed,
            normalize=normalize,
            delimiter=",")
    dataset_len = len(wine_dataset)
    train_len = int(dataset_len*splitting_part)
    test_len = dataset_len - train_len
    wine_trainset, wine_testset = random_split(wine_dataset,
            lengths=[train_len, test_len])
    return wine_trainset, wine_testset 
